@@ -1,8 +1,6 @@
-use super::types::*;
-use crate::Client;
+use crate::{interface::types::Interface, Client};
 use color_eyre::Report;
 use reqwest::{Method, Request};
-use tracing::debug;
 
 pub async fn list(client: &mut Client) -> Result<Vec<Interface>, Report> {
     let url = client.base_url.clone();
@@ -18,7 +16,6 @@ pub async fn list(client: &mut Client) -> Result<Vec<Interface>, Report> {
 pub async fn get(client: &mut Client, ifid: &str) -> Result<Interface, Report> {
     let url = client.base_url.clone();
     let url = url.join(&format!("{}/{}", super::BASE, ifid))?;
-    debug!("url {}", url);
 
     let req = Request::new(Method::GET, url);
 
